@@ -13,8 +13,9 @@ class SSLifyAdminMiddleware(object):
 
     def process_request(self, request):
         sslify_admin_namespace = getattr(settings, 'SSLIFY_ADMIN_NAMESPACE', 'admin')
+        sslify_admin_disable = getattr(settings, 'SSLIFY_ADMIN_DISABLE', settings.DEBUG)
         if request.path.startswith(reverse('%s:index' % sslify_admin_namespace)) and \
-                not (settings.DEBUG or request.is_secure()):
+                not (sslify_admin_disable or request.is_secure()):
             url = request.build_absolute_uri(request.get_full_path())
             secure_url = url.replace('http://', 'https://')
             return HttpResponsePermanentRedirect(secure_url)
